function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import { IconContext } from 'phosphor-react';
import React, { useCallback, useEffect, useMemo, useRef, useState } from 'react';
import styled, { keyframes } from 'styled-components';
import { cv } from '../../style';
import { Button } from '..';
const ActionBoxDiv = styled.div`
    display: flex;
    align-items: center;
    position: relative;
    width: fit-content;
    user-select: none;
`;
const FadeInFromTop = keyframes`
    0% {
        transform: translateY(-4px);
        opacity: 0;
    }
    100% {
        transform: translateY(0px);
        opacity: 1;
    }
`;
const FadeInFromBottom = keyframes`
    0% {
        transform: translateY(4px);
        opacity: 0;
    }
    100% {
        transform: translateY(0px);
        opacity: 1;
    }
`;
const OverlayDiv = styled.div`
    position: absolute;
    min-width: 230px;
    ${props => props.top !== undefined && `top: ${props.top + props.buttonHeight}px;`};
    ${props => props.right !== undefined && `right: ${props.right}px;`};
    ${props => props.bottom !== undefined && `bottom: ${props.bottom + props.buttonHeight}px;`};
    ${props => props.left !== undefined && `left: ${props.left}px;`};
    padding: ${props => props.removePadding ? '0px' : '8px 16px'};
    box-shadow: 0 8px 30px rgba(0, 0, 0, 10%);
    background-color: ${cv.bg_element1};
    font-size: 14px;
    display: flex;
    flex-direction: column;
    gap: 0px;
    z-index: 10;
    border-radius: 6px;
    border: solid 1px ${cv.border3};
    animation: ${props => props.top !== undefined ? FadeInFromTop : FadeInFromBottom} 150ms
        cubic-bezier(0.07, 0.75, 0.54, 0.93);
`;

/**
 * 클릭했을 때 오버레이를 표시하는 버튼입니다.
 *
 * \<Button\>에서 확장되었습니다.
 */
export function ActionBox({
  children,
  removePadding,
  overlay,
  ...props
}) {
  const [isOpen, setIsOpen] = useState(false);
  const [direction, setDirection] = useState({});
  const ref = useRef(null);
  const buttonRef = useRef(null);
  const overlayRef = useRef(null);
  useEffect(() => {
    function handleClickOutside(e) {
      if (ref.current && !ref.current.contains(e.target)) {
        setIsOpen(false);
      }
    }

    document.addEventListener('mousedown', handleClickOutside);
    return () => {
      document.removeEventListener('mousedown', handleClickOutside);
    };
  }, [ref]);
  const calcPos = useCallback(() => {
    if (!ref.current) return;
    const pos = {};

    if (ref.current.getBoundingClientRect().right + 250 > (window.innerWidth >= 1200 ? (window.innerWidth - 1200) / 2 + 1200 : window.innerWidth)) {
      pos.right = 0;
    } else {
      pos.left = 0;
    }

    if (ref.current.getBoundingClientRect().bottom + 300 > window.innerHeight) {
      pos.bottom = 0;
    } else {
      pos.top = 0;
    }

    setDirection(pos);
  }, []);
  const IconStyle = useMemo(() => ({
    size: 16,
    weight: 'bold',
    color: cv.text3
  }), []);
  return /*#__PURE__*/React.createElement(ActionBoxDiv, {
    ref: ref
  }, /*#__PURE__*/React.createElement(Button, _extends({}, props, {
    ref: buttonRef,
    onClick: () => {
      calcPos();
      setIsOpen(!isOpen);
      if (props.onClick) props.onClick();
    }
  }), children), /*#__PURE__*/React.createElement(IconContext.Provider, {
    value: IconStyle
  }, isOpen && /*#__PURE__*/React.createElement(OverlayDiv, _extends({}, direction, {
    ref: overlayRef,
    buttonHeight: buttonRef.current?.offsetHeight && buttonRef.current.offsetHeight + 2 || 32,
    removePadding: removePadding
  }), overlay)));
}