import React, { useState } from 'react';
import styled from 'styled-components';
import { cv } from '../../style';
const ToolTipBox = styled.div`
    position: absolute;
    opacity: 0;
    visibility: hidden;
    transition: 100ms;

    background-color: ${cv.bg_element5};
    color: ${cv.text5};
    font-size: 12px;
    border-radius: 6px;
    padding: 4px 8px;
    white-space: pre;
    pointer-events: none;

    &::after {
        content: '';
        position: absolute;
        border-style: solid;
        border-width: 5px;
        pointer-events: none;
    }
`;
const Divver = styled.div`
    width: fit-content;
    height: fit-content;
    position: relative;
    z-index: 1000;

    ${props => props.isHover && `
        ${ToolTipBox} {
            visibility: visible;
            opacity: 1;
        }
    `}
`;
const ToolTipBoxTop = styled(ToolTipBox)`
    transform: translate(-50%, 0%);
    left: 50%;
    bottom: 130%;

    &::after {
        top: 100%;
        left: 50%;
        transform: translate(-50%, 0%);
        border-color: ${cv.bg_element5} transparent transparent transparent;
    }
`;
const ToolTipBoxBottom = styled(ToolTipBox)`
    transform: translate(-50%, 0%);
    left: 50%;
    top: 120%;

    &::after {
        bottom: 100%;
        left: 50%;
        transform: translate(-50%, 0%);
        border-color: transparent transparent ${cv.bg_element5} transparent;
    }
`;
const ToolTipBoxRight = styled(ToolTipBox)`
    transform: translate(0%, 50%);
    left: 110%;

    &::after {
        top: 25%;
        right: 100%;
        border-color: transparent ${cv.bg_element5} transparent transparent;
    }
`;
const ToolTipBoxLeft = styled(ToolTipBox)`
    /* transform: translate(0%, 50%); */
    right: 110%;

    &::after {
        top: 35%;
        left: 100%;
        border-color: transparent transparent transparent ${cv.bg_element5};
    }
`;

/**
 * 마우스를 올렸을 때 툴팁을 표시합니다.
 */
export function ToolTip({
  children,
  text,
  direction
}) {
  const [isHover, setIsHover] = useState(false);
  let box;

  switch (direction) {
    case 'top':
      box = /*#__PURE__*/React.createElement(ToolTipBoxTop, null, text);
      break;

    case 'bottom':
      box = /*#__PURE__*/React.createElement(ToolTipBoxBottom, null, text);
      break;

    case 'right':
      box = /*#__PURE__*/React.createElement(ToolTipBoxRight, null, text);
      break;

    case 'left':
      box = /*#__PURE__*/React.createElement(ToolTipBoxLeft, null, text);
      break;

    default:
      box = /*#__PURE__*/React.createElement(ToolTipBoxTop, null, text);
      break;
  }

  return /*#__PURE__*/React.createElement(Divver, {
    isHover: isHover,
    onMouseOver: () => setIsHover(true),
    onMouseOut: () => setIsHover(false),
    className: "tooltip"
  }, box, children);
}