import React, { createContext, useCallback, useMemo, useState } from 'react';
import { Modal } from '../../components/modal';
export const ModalContext = /*#__PURE__*/createContext({
  isOpen: false,
  open: () => null,
  close: () => null,
  width: 350
});

function ModalContextProvider({
  children
}) {
  const [isOpen, setOpen] = useState(false);
  const [modalContent, setModalContent] = useState('');
  const [width, setWidth] = useState(350);
  const [title, setTitle] = useState();
  const [isPadding, setPadding] = useState(true);
  const open = useCallback((content, option) => {
    setOpen(true);
    setTitle(option?.title);
    setWidth(option?.width || 300);
    setModalContent(content);
    setPadding(option?.isPadding === undefined ? true : option?.isPadding);
  }, []);
  const close = useCallback(() => {
    setOpen(false);
  }, []);
  const value = useMemo(() => ({
    isOpen,
    open,
    close,
    width,
    title
  }), [close, isOpen, open, title, width]);
  return /*#__PURE__*/React.createElement(ModalContext.Provider, {
    value: value
  }, /*#__PURE__*/React.createElement(Modal, {
    setOpen: setOpen,
    isOpen: isOpen,
    content: modalContent,
    width: width,
    title: title,
    close: () => setOpen(false),
    isPadding: isPadding
  }), children);
}

export default ModalContextProvider;